==> qtjambi-help-5.15-sources.jar: io/qt/help/QHelpContentItem.java <==
package io.qt.help;


/**
 * <p>Item for use with QHelpContentModel</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qhelpcontentitem.html">QHelpContentItem</a></p>
 */
public final class QHelpContentItem extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentitem.html#child">QHelpContentItem::child(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpContentItem child(int row){
        return child_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), row);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpContentItem child_native_int_constfct(long __this__nativeId, int row);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentitem.html#childCount">QHelpContentItem::childCount()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int childCount(){
        return childCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int childCount_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentitem.html#childPosition">QHelpContentItem::childPosition(QHelpContentItem*)const</a></p>
     */
    @io.qt.QtUninvokable
    public final int childPosition(io.qt.help.QHelpContentItem child){
        return childPosition_native_QHelpContentItem_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(child));
    }
    
    @io.qt.QtUninvokable
    private native int childPosition_native_QHelpContentItem_ptr_constfct(long __this__nativeId, long child);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentitem.html#parent">QHelpContentItem::parent()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpContentItem parent(){
        return parent_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpContentItem parent_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentitem.html#row">QHelpContentItem::row()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int row(){
        return row_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int row_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentitem.html#title">QHelpContentItem::title()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpcontentitem.html#url">QHelpContentItem::url()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpContentItem(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-help-6.2.7-sources.jar: io/qt/help/QHelpContentItem.java <==
package io.qt.help;


/**
 * <p>Item for use with QHelpContentModel</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qhelpcontentitem.html">QHelpContentItem</a></p>
 */
public final class QHelpContentItem extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentitem.html#child">QHelpContentItem::child(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpContentItem child(int row){
        return child_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), row);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpContentItem child_native_int_constfct(long __this__nativeId, int row);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentitem.html#childCount">QHelpContentItem::childCount()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int childCount(){
        return childCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int childCount_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentitem.html#childPosition">QHelpContentItem::childPosition(QHelpContentItem*)const</a></p>
     */
    @io.qt.QtUninvokable
    public final int childPosition(io.qt.help.QHelpContentItem child){
        return childPosition_native_QHelpContentItem_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(child));
    }
    
    @io.qt.QtUninvokable
    private native int childPosition_native_QHelpContentItem_ptr_constfct(long __this__nativeId, long child);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentitem.html#parent">QHelpContentItem::parent()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpContentItem parent(){
        return parent_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpContentItem parent_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentitem.html#row">QHelpContentItem::row()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int row(){
        return row_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int row_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentitem.html#title">QHelpContentItem::title()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpcontentitem.html#url">QHelpContentItem::url()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpContentItem(QPrivateConstructor p) { super(p); } 
    
}
